@@ -539,8 +539,12 @@ class Reaction(object):
 
     def check_consistent_units(self, throw=False):
         if is_quantity(self.param):  # This will assume mass action
+            if isinstance(self.param.item(), Expr):
+                param = self.param.item()({"temperature": 1*default_units.K})*self.param.units
+            else:
+                param = self.param
             try:
-                to_unitless(self.param/(
+                to_unitless(param/(
                     default_units.molar**(1-self.order())/default_units.s))
             except Exception:
                 if throw:
@@ -1145,7 +1149,7 @@ def _solve_balancing_ilp_pulp(A):
     prob += reduce(add, x)
     for expr in [pulp.lpSum([x[i]*e for i, e in enumerate(row)]) for row in A.tolist()]:
         prob += expr == 0
-    prob.solve()
+    prob.solve(pulp.PULP_CBC_CMD(msg=False))
     return [pulp.value(_) for _ in x]
 
 
