@@ -5,11 +5,12 @@ Module for dealing with constants `Henry's law
 """
 from __future__ import absolute_import, division, print_function
 
+from ._util import get_backend
 from .util.pyutil import defaultnamedtuple, deprecated
 from .units import default_units
 
 
-def Henry_H_at_T(T, H, Tderiv, T0=None, units=None, exp=None):
+def Henry_H_at_T(T, H, Tderiv, T0=None, units=None, backend=None):
     """ Evaluate Henry's constant H at temperature T
 
     Parameters
@@ -20,28 +21,23 @@ def Henry_H_at_T(T, H, Tderiv, T0=None, units=None, exp=None):
         Henry's constant
     Tderiv: float (optional)
         dln(H)/d(1/T), assumed to be in Kelvin if ``units == None``.
-        default: 298.15 K
     T0: float
         Reference temperature, assumed to be in Kelvin if ``units == None``
+        default: 298.15 K
     units: object (optional)
         object with attributes: kelvin (e.g. chempy.units.default_units)
-    exp: callback (optional)
-        callback for calculating the exponential, default: numpy.exp, math.exp
+    backend : module (optional)
+        module with "exp", default: numpy, math
 
     """
-    if exp is None:
-        try:
-            from numpy import exp
-        except ImportError:
-            from math import exp
-
+    be = get_backend(backend)
     if units is None:
         K = 1
     else:
         K = units.Kelvin
     if T0 is None:
         T0 = 298.15*K
-    return H * exp(Tderiv*(1/T - 1/T0))
+    return H * be.exp(Tderiv*(1/T - 1/T0))
 
 
 class Henry(defaultnamedtuple('Henry', 'Hcp Tderiv T0 ref', [None, None])):
@@ -53,11 +49,11 @@ class Henry(defaultnamedtuple('Henry', 'Hcp Tderiv T0 ref', [None, None])):
 
     Parameters
     ----------
-    kH0: float
+    Hcp: float
         Henry's constant [M/atm]
-    derivative: float
+    Tderiv: float
         dln(kH)/d(1/T) [K]
-        Equivalent to \Delta_soln H / R
+        Equivalent to $\\Delta_{soln}H / R$
     ref: object
         Reference for origin of parameters
     units: object (optional)
@@ -71,9 +67,10 @@ class Henry(defaultnamedtuple('Henry', 'Hcp Tderiv T0 ref', [None, None])):
 
     """
 
-    def __call__(self, T, units=None, exp=None):
+    def __call__(self, T, units=None, backend=None):
         """ Evaluates Henry's constant for provided temperature """
-        return Henry_H_at_T(T, self.Hcp, self.Tderiv, self.T0, units=units)
+        return Henry_H_at_T(T, self.Hcp, self.Tderiv, self.T0,
+                            units=units, backend=backend)
 
     @deprecated('0.3.1', '0.5.0', __call__)
     def get_kH_at_T(self, *args, **kwargs):
@@ -91,7 +88,7 @@ class Henry(defaultnamedtuple('Henry', 'Hcp Tderiv T0 ref', [None, None])):
             Temperature
         P: float
             Pressure
-        \*\*kwargs:
+        \\*\\*kwargs:
             Keyword arguments passed on to :meth:`__call__`
 
         """
@@ -109,7 +106,7 @@ class Henry(defaultnamedtuple('Henry', 'Hcp Tderiv T0 ref', [None, None])):
             Temperature
         P: float
             Pressure
-        \*\*kwargs:
+        \\*\\*kwargs:
             Keyword arguments passed on to :meth:`__call__`
         """
         return c / self(T, **kwargs)
@@ -126,6 +123,6 @@ class HenryWithUnits(Henry):
     '0.00097'
 
     """
-    def __call__(self, T, units=default_units, exp=None):
+    def __call__(self, T, units=default_units, backend=None):
         """ Evaluates Henry's constant for provided temperature """
-        return super(HenryWithUnits, self).__call__(T, units, exp)
+        return super(HenryWithUnits, self).__call__(T, units, backend)
