@@ -1,5 +1,6 @@
 from operator import itemgetter
 from .printer import Printer
+from ..units import is_quantity
 
 
 class StrPrinter(Printer):
@@ -42,9 +43,9 @@ class StrPrinter(Printer):
             magnitude_str = mag_fmt(rxn.param.magnitude)
             unit_str = unit_fmt(rxn.param.dimensionality)
         except AttributeError:
-            try:
+            if is_quantity(rxn.param) or isinstance(rxn.param, (float,)):
                 return mag_fmt(rxn.param)
-            except TypeError:
+            else:
                 return str(rxn.param)
         else:
             return magnitude_str + self._str(' ') + unit_str
