@@ -1,5 +1,6 @@
 import warnings
-
+from chempy.util.testing import requires
+from chempy.units import units_library
 from ..water_diffusivity_holz_2000 import water_self_diffusion_coefficient as w_sd
 
 
@@ -22,13 +23,12 @@ def test_water_self_diffusion_coefficient():
         raise
     warnings.resetwarnings()
 
-    try:
-        from chempy.units import allclose, linspace, default_units as u
-    except ImportError:
-        pass
-    else:
-        unit = u.m**2/u.s
-        assert allclose(1e9*w_sd(298.15*u.K, units=u),
-                        2.299*unit, rtol=1e-3, atol=1e-8*unit)
-        assert allclose(1e9*w_sd(linspace(297, 299)*u.K, units=u),
-                        2.299*u.m**2/u.s, rtol=5e-2, atol=1e-2*unit)
+
+@requires(units_library)
+def test_water_self_diffusion_coefficient__units():
+    from chempy.units import allclose, linspace, default_units as u
+    unit = u.m**2/u.s
+    assert allclose(1e9*w_sd(298.15*u.K, units=u),
+                    2.299*unit, rtol=1e-3, atol=1e-8*unit)
+    assert allclose(1e9*w_sd(linspace(297, 299)*u.K, units=u),
+                    2.299*u.m**2/u.s, rtol=5e-2, atol=1e-2*unit)
