@@ -3,6 +3,7 @@ from __future__ import (absolute_import, division, print_function)
 
 from functools import reduce
 from operator import attrgetter, add
+import sys
 
 import pytest
 
@@ -15,6 +16,10 @@ from ..chemistry import (
     Equilibrium, balance_stoichiometry
 )
 
+if sys.version_info < (3, 6, 0):
+    class ModuleNotFoundError(ImportError):
+        pass
+
 
 @requires('numpy')
 def test_equilibrium_quotient():
@@ -315,6 +320,14 @@ def test_balance_stoichiometry():
     assert r6 == dict(CuSCN=4, KIO3=7, HCl=14)
     assert p6 == dict(CuSO4=4, KCl=7, HCN=4, ICl=7, H2O=5)
 
+    r7, p7 = balance_stoichiometry({'Zn+2', 'e-'}, {'Zn'})
+    assert r7 == {'Zn+2': 1, 'e-': 2}
+    assert p7 == {'Zn': 1}
+
+    r8, p8 = balance_stoichiometry({'Zn'}, {'Zn+2', 'e-'})
+    assert r8 == {'Zn': 1}
+    assert p8 == {'Zn+2': 1, 'e-': 2}
+
 
 @requires('sympy')
 def test_balance_stoichiometry__ordering():
@@ -332,17 +345,23 @@ def test_balance_stoichiometry__simple():
     assert p2 == {'Na2O': 1, 'CO2': 1}
 
 
-@requires('sympy')
+@requires('sympy', 'pulp')
 @pytest.mark.parametrize('underdet', [False, None, True])
 def test_balance_stoichiometry__impossible(underdet):
-    from pulp.solvers import PulpSolverError
+    try:
+        from pulp import PulpSolverError
+    except ModuleNotFoundError:
+        from pulp.solvers import PulpSolverError  # older version of PuLP
     with pytest.raises((ValueError, PulpSolverError)):
         r1, p1 = balance_stoichiometry({'CO'}, {'CO2'}, underdetermined=underdet)
 
 
 @requires('sympy', 'pulp')
 def test_balance_stoichiometry__underdetermined():
-    from pulp.solvers import PulpSolverError
+    try:
+        from pulp import PulpSolverError
+    except ModuleNotFoundError:
+        from pulp.solvers import PulpSolverError  # older version of PuLP
 
     with pytest.raises(ValueError):
         balance_stoichiometry({'C2H6', 'O2'}, {'H2O', 'CO2', 'CO'}, underdetermined=False)
