@@ -20,6 +20,7 @@ from __future__ import (absolute_import, division, print_function)
 from functools import reduce
 from operator import mul
 import sys
+import warnings
 
 from .util.arithmeticdict import ArithmeticDict
 from .util.pyutil import NameSpace, deprecated
@@ -114,6 +115,13 @@ def magnitude(value):
         return value
 
 
+def uncertainty(uval):
+    uncert = uval.uncertainty
+    if not is_quantity(uncert):
+        warnings.warn(f"Handling unexpected type: {type(uval)}")
+    return uncert
+
+
 def simplified(value):
     if hasattr(value, 'simplified'):
         return value.simplified
@@ -127,6 +135,14 @@ def is_quantity(arg):
     else:
         return False
 
+# SI Base Quantities:
+time = ArithmeticDict(int, {'time': 1})
+length = ArithmeticDict(int, {'length': 1})
+mass = ArithmeticDict(int, {'mass': 1})
+current = ArithmeticDict(int, {'current': 1})
+temperature = ArithmeticDict(int, {'temperature': 1})
+amount = ArithmeticDict(int, {'amount': 1})
+# intensity = ArithmeticDict(int, {'intensity': 1}) what's wrong with photon flux? (human eyes, bah!)
 
 energy = ArithmeticDict(int, {'mass': 1, 'length': 2, 'time': -2})
 volume = ArithmeticDict(int, {'length': 3})
@@ -272,7 +288,7 @@ def is_unitless(expr):
 
     """
     if hasattr(expr, 'dimensionality'):
-        if expr == pq.dimensionless:
+        if expr.dimensionality == pq.dimensionless:
             return True
         else:
             return expr.simplified.dimensionality == pq.dimensionless.dimensionality
@@ -475,6 +491,11 @@ def compare_equality(a, b):
 
 def allclose(a, b, rtol=1e-8, atol=None):
     """ Analogous to ``numpy.allclose``. """
+    if a.__class__.__name__ == "UncertainQuantity":
+        return allclose(pq.Quantity(a), b, rtol=rtol, atol=atol)
+    if b.__class__.__name__ == "UncertainQuantity":
+        return allclose(a, pq.Quantity(b), rtol=rtol, atol=atol)
+
     try:
         d = abs(a - b)
     except Exception:
