@@ -14,10 +14,18 @@ from chempy.units import (
 )
 from ..testing import requires
 from ..pyutil import defaultkeydict
-from .._expr import Expr, mk_Poly, mk_PiecewisePoly, create_Piecewise, create_Poly, Log10
+from .._expr import Expr, mk_Poly, mk_PiecewisePoly, create_Piecewise, create_Poly, Log10, Constant, Symbol as _Symbol
 from ..parsing import parsing_library
 
 
+def test_Constant():
+    c23 = Constant(2.3)
+    assert abs(2.3 - float(c23)) < 1e-15
+
+    c_div = Constant(2.3)/Constant(3.4)
+    assert abs(2.3/3.4 - float(c_div)) < 1e-15
+
+
 class HeatCapacity(Expr):
     parameter_keys = ('temperature',)
 
@@ -49,6 +57,8 @@ def test_Expr():
     cv = _get_cv()
     _ref = 0.8108020083055849
     assert abs(cv['Al']({'temperature': 273.15, 'molar_gas_constant': 8.3145}) - _ref) < 1e-14
+    with pytest.raises(Exception):
+        float(cv['Al'])
 
 
 def _poly(args, x, backend=None):
@@ -319,7 +329,6 @@ def test_BinaryExpr():
     assert -(-p1) == p1
 
 
-@pytest.mark.slow
 @requires('sympy')
 def test_Expr__latex():
     Poly = Expr.from_callback(_poly, parameter_keys=('x',), argument_names=('x0', Ellipsis))
@@ -540,3 +549,13 @@ def test_implicit_str():
     assert abs(expr2({'x': 3, 'u': 5}) - 5/(1 + 2*3 + 3*9)) < 1e-12
     assert expr1.all_parameter_keys() == set(['x'])
     assert expr2.all_parameter_keys() == set(['x'])
+
+
+def test_Symbol():
+    a = _Symbol.fk("a")
+    b = _Symbol.fk("b")
+    assert not a == b
+    assert not a == b*0
+    assert not a == 0*b
+    assert not a*-0.0 == b*0.0
+    assert not a*0.0 == b*-0.0
