@@ -11,6 +11,7 @@ from chempy.util.table import (
     rsys2tablines, rsys2table, rsys2pdf_table
 )
 from .test_graph import _get_rsys
+from ..testing import skipif
 
 
 try:
@@ -43,9 +44,8 @@ Id. & Reactants &  & Products & {Rate constant} & Unit & Ref \\
 \end{table}""")
 
 
-@pytest.mark.slow
 @pytest.mark.parametrize('longtable', (True, False))
-@pytest.mark.skipif(pdflatex_missing, reason='latex not installed? (pdflatex command missing)')
+@skipif(pdflatex_missing, reason='latex not installed? (pdflatex command missing)')
 def test_rsys2pdf_table(longtable):
     rsys = _get_rsys()
     tempdir = tempfile.mkdtemp()
@@ -55,7 +55,6 @@ def test_rsys2pdf_table(longtable):
         shutil.rmtree(tempdir)
 
 
-@pytest.mark.slow
 @pytest.mark.skipif(pdflatex_missing, reason='latex not installed? (pdflatex command missing)')
 def test_rsys2pdf_table_no_output_dir():
     rsys = _get_rsys()
